==> OOo_2.0.0_Win32Intel_solver_curvirgo_other.zip: solver/680/wntmsci10.pro/inc/com/sun/star/script/provider/ScriptErrorRaisedException.hpp <==
#ifndef _COM_SUN_STAR_SCRIPT_PROVIDER_SCRIPTERRORRAISEDEXCEPTION_HPP_
#define _COM_SUN_STAR_SCRIPT_PROVIDER_SCRIPTERRORRAISEDEXCEPTION_HPP_

#ifndef _SAL_CONFIG_H_
#include "sal/config.h"
#endif

#ifndef _COM_SUN_STAR_SCRIPT_PROVIDER_SCRIPTERRORRAISEDEXCEPTION_HDL_
#include "com/sun/star/script/provider/ScriptErrorRaisedException.hdl"
#endif

#ifndef _COM_SUN_STAR_UNO_EXCEPTION_HPP_
#include "com/sun/star/uno/Exception.hpp"
#endif
#ifndef _COM_SUN_STAR_UNO_TYPE_HXX_
#include "com/sun/star/uno/Type.hxx"
#endif
#ifndef _OSL_MUTEX_HXX_
#include "osl/mutex.hxx"
#endif
#ifndef _RTL_USTRING_HXX_
#include "rtl/ustring.hxx"
#endif
#ifndef _SAL_TYPES_H_
#include "sal/types.h"
#endif

namespace com { namespace sun { namespace star { namespace script { namespace provider {

inline ScriptErrorRaisedException::ScriptErrorRaisedException() SAL_THROW( () )
    : ::com::sun::star::uno::Exception()
    , scriptName()
    , language()
    , lineNum(0)
{ }

inline ScriptErrorRaisedException::ScriptErrorRaisedException(const ::rtl::OUString& Message_, const ::com::sun::star::uno::Reference< ::com::sun::star::uno::XInterface >& Context_, const ::rtl::OUString& scriptName_, const ::rtl::OUString& language_, const ::sal_Int32& lineNum_) SAL_THROW( () )
    : ::com::sun::star::uno::Exception(Message_, Context_)
    , scriptName(scriptName_)
    , language(language_)
    , lineNum(lineNum_)
{ }

ScriptErrorRaisedException::ScriptErrorRaisedException(ScriptErrorRaisedException const & the_other): ::com::sun::star::uno::Exception(the_other), scriptName(the_other.scriptName), language(the_other.language), lineNum(the_other.lineNum) {}

ScriptErrorRaisedException::~ScriptErrorRaisedException() {}

ScriptErrorRaisedException & ScriptErrorRaisedException::operator =(ScriptErrorRaisedException const & the_other) {
    //TODO: Just like its implicitly-defined counterpart, this function definition is not exception-safe
    ::com::sun::star::uno::Exception::operator =(the_other);
    scriptName = the_other.scriptName;
    language = the_other.language;
    lineNum = the_other.lineNum;
    return *this;
}

} } } } }

inline const ::com::sun::star::uno::Type& SAL_CALL getCppuType( const ::com::sun::star::script::provider::ScriptErrorRaisedException* ) SAL_THROW( () )
{
    static typelib_TypeDescriptionReference * the_type = 0;
    if ( !the_type )
    {
        typelib_static_type_init( &the_type, typelib_TypeClass_EXCEPTION, "com.sun.star.script.provider.ScriptErrorRaisedException" );
    }
    return * reinterpret_cast< ::com::sun::star::uno::Type * >( &the_type );
}

#endif // _COM_SUN_STAR_SCRIPT_PROVIDER_SCRIPTERRORRAISEDEXCEPTION_HPP_

==> OOo_2.0.3_Win32Intel_solver_curvirgo_other.zip: solver/680/wntmsci10.pro/inc/com/sun/star/script/provider/ScriptErrorRaisedException.hpp <==
#ifndef _COM_SUN_STAR_SCRIPT_PROVIDER_SCRIPTERRORRAISEDEXCEPTION_HPP_
#define _COM_SUN_STAR_SCRIPT_PROVIDER_SCRIPTERRORRAISEDEXCEPTION_HPP_

#ifndef _SAL_CONFIG_H_
#include "sal/config.h"
#endif

#ifndef _COM_SUN_STAR_SCRIPT_PROVIDER_SCRIPTERRORRAISEDEXCEPTION_HDL_
#include "com/sun/star/script/provider/ScriptErrorRaisedException.hdl"
#endif

#ifndef _COM_SUN_STAR_UNO_EXCEPTION_HPP_
#include "com/sun/star/uno/Exception.hpp"
#endif
#ifndef _COM_SUN_STAR_UNO_TYPE_HXX_
#include "com/sun/star/uno/Type.hxx"
#endif
#ifndef INCLUDED_CPPU_UNOTYPE_HXX
#include "cppu/unotype.hxx"
#endif
#ifndef _OSL_MUTEX_HXX_
#include "osl/mutex.hxx"
#endif
#ifndef _RTL_USTRING_HXX_
#include "rtl/ustring.hxx"
#endif
#ifndef _SAL_TYPES_H_
#include "sal/types.h"
#endif

namespace com { namespace sun { namespace star { namespace script { namespace provider {

inline ScriptErrorRaisedException::ScriptErrorRaisedException() SAL_THROW( () )
    : ::com::sun::star::uno::Exception()
    , scriptName()
    , language()
    , lineNum(0)
{ }

inline ScriptErrorRaisedException::ScriptErrorRaisedException(const ::rtl::OUString& Message_, const ::com::sun::star::uno::Reference< ::com::sun::star::uno::XInterface >& Context_, const ::rtl::OUString& scriptName_, const ::rtl::OUString& language_, const ::sal_Int32& lineNum_) SAL_THROW( () )
    : ::com::sun::star::uno::Exception(Message_, Context_)
    , scriptName(scriptName_)
    , language(language_)
    , lineNum(lineNum_)
{ }

ScriptErrorRaisedException::ScriptErrorRaisedException(ScriptErrorRaisedException const & the_other): ::com::sun::star::uno::Exception(the_other), scriptName(the_other.scriptName), language(the_other.language), lineNum(the_other.lineNum) {}

ScriptErrorRaisedException::~ScriptErrorRaisedException() {}

ScriptErrorRaisedException & ScriptErrorRaisedException::operator =(ScriptErrorRaisedException const & the_other) {
    //TODO: Just like its implicitly-defined counterpart, this function definition is not exception-safe
    ::com::sun::star::uno::Exception::operator =(the_other);
    scriptName = the_other.scriptName;
    language = the_other.language;
    lineNum = the_other.lineNum;
    return *this;
}

} } } } }

namespace com { namespace sun { namespace star { namespace script { namespace provider {

inline ::com::sun::star::uno::Type const & cppu_detail_getUnoType(::com::sun::star::script::provider::ScriptErrorRaisedException const *) {
    static typelib_TypeDescriptionReference * the_type = 0;
    if ( !the_type )
    {
        typelib_static_type_init( &the_type, typelib_TypeClass_EXCEPTION, "com.sun.star.script.provider.ScriptErrorRaisedException" );
    }
    return * reinterpret_cast< ::com::sun::star::uno::Type * >( &the_type );
};

} } } } }

inline ::com::sun::star::uno::Type const & SAL_CALL getCppuType(::com::sun::star::script::provider::ScriptErrorRaisedException const *) SAL_THROW(()) {
    return ::cppu::UnoType< ::com::sun::star::script::provider::ScriptErrorRaisedException >::get();
}

#endif // _COM_SUN_STAR_SCRIPT_PROVIDER_SCRIPTERRORRAISEDEXCEPTION_HPP_
